package VMOMI::HostRuntimeInfoNetStackInstanceRuntimeInfoState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
